@@ -348,7 +348,7 @@ class I2CSensor(Sensor):
         Read an signed 16-bit value from the specified register, in little
         endian byte order.
         """
-        out = self.getU16(reg1, reg2)
+        out = self.bytes_to_u16(reg1, reg2)
         if out is not None:
             if out > 32767:
                 out -= 65536
