@@ -120,15 +120,21 @@ class MAX31865(SPISensor):
         """
         Fetch data from sensor and write to default data layout defined in the base class
         """
-        self.setup()
         data = self.default_data()
-        data["values"] = {}
-        data["values"]["temperature"] = {
-            "value": self.temperature,
-            "unit": self._units["temperature"],
-        }
-        data["error"] = False
-        return data
+
+        try:
+            self.setup()
+        except SpiIOError:
+            self.disconnected_ftdi = True
+        else:
+            data["values"] = {}
+            data["values"]["temperature"] = {
+                "value": self.temperature,
+                "unit": self._units["temperature"],
+            }
+            data["error"] = False
+        finally:
+            return data
 
     @property
     def bias(self):
