@@ -122,11 +122,12 @@ class SFM3XXX(I2CSensor):
 
         return self.error
 
-    def get_data(self, scale_factor=140.0, offset=32000.0):
+    def get_data(self, scale_factor: int = 140, offset: int = 32000):
         """
-        :param scale_factor: [INT] sensor specific parameter for the calculation of the volume flow
-        :param offset: [INT] sensor specific parameter for the calculation of the volume flow
-        :return: [DICT] data dictionary
+        :param scale_factor: sensor specific parameter for the calculation of the volumeflow
+        :param offset: sensor specific parameter for the calculation of the volumeflow
+        :return: data dictionary
+        :rtype: dict
         """
         res = self.txrx([], readlen=3)
         self._logger.debug("Result bytes: %s", res)
